#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 monad-logger
version:              0.3.42
visibility:           public
id:                   monad-logger-0.3.42-3YcMDDc7EteKLZ4yiGpkvO
key:                  monad-logger-0.3.42-3YcMDDc7EteKLZ4yiGpkvO
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/monad-logger#readme
synopsis:             A class of monads which can log messages.
description:
    See README and Haddocks at <https://www.stackage.org/package/monad-logger>

category:             System
abi:                  29d7f9be31190f426e77632df1aa7d88
exposed:              True
exposed-modules:      Control.Monad.Logger Control.Monad.Logger.CallStack
hidden-modules:       Paths_monad_logger
import-dirs:          /usr/lib/ghc-9.6.6/site-local/monad-logger-0.3.42
library-dirs:         /usr/lib/ghc-9.6.6/site-local/monad-logger-0.3.42
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/monad-logger-0.3.42
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monad-logger
hs-libraries:         HSmonad-logger-0.3.42-3YcMDDc7EteKLZ4yiGpkvO
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-4cc2yOSL2sy5iK6rZQd5vm
    conduit-extra-1.3.8-KyGJKsBlxeR6aLyGVSa94z exceptions-0.10.7
    fast-logger-3.2.4-99dKOz2cOoJKRGdMQREJkb
    lifted-base-0.2.3.12-2iTkngyrdjxFbaCyw0Ft3U
    monad-control-1.0.3.1-Cu2gag9g9XfDkjDNf9i6xZ
    monad-loops-0.4.3-LG7facWXNYz9W52syv7lz8 mtl-2.3.1
    resourcet-1.2.6-Dhf0zTJRCL3LnKPExtEFW6 stm-2.5.1.0
    stm-chans-3.0.0.9-FlU5K8NwXr3CuyuM0prvJs template-haskell-2.20.0.0
    text-2.0.2 transformers-0.6.1.0
    transformers-base-0.4.6-EvxeInxseF6GyjY0h0BJce
    transformers-compat-0.7.2-LmnlcpbfHuuAOWEWPuyobH
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY

haddock-interfaces:
    /usr/share/doc/haskell-monad-logger/html/monad-logger.haddock

haddock-html:         /usr/share/doc/haskell-monad-logger/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

